@@ -20,6 +20,7 @@ pub use crate::core::constraint::*;
 pub use crate::core::direction::{Direction, In, InOut, Local, Out};
 pub use crate::core::logic;
 pub use crate::core::logic::Logic;
+pub use crate::core::logic::LogicJoin;
 pub use crate::core::logic::LogicLink;
 pub use crate::core::module_defines::ModuleDefines;
 pub use crate::core::module_defines::{generate_verilog, generate_verilog_unchecked};
@@ -27,6 +28,9 @@ pub use crate::core::named_path::NamedPath;
 pub use crate::core::probe;
 pub use crate::core::probe::Probe;
 pub use crate::core::signal::Signal;
+pub use crate::core::signed::{
+    signed, signed_bit_cast, signed_cast, unsigned_bit_cast, unsigned_cast, Signed,
+};
 pub use crate::core::simulate::simulate;
 pub use crate::core::simulate::{Sim, SimError, Simulation};
 pub use crate::core::synth::Synth;
@@ -45,4 +49,3 @@ pub use crate::wait_clock_cycles;
 pub use crate::wait_clock_false;
 pub use crate::wait_clock_true;
 pub use rust_hdl_macros::{hdl_gen, LogicBlock, LogicInterface, LogicState};
-pub use crate::core::signed::{Signed, signed_bit_cast, unsigned_bit_cast, signed, signed_cast, unsigned_cast};
\ No newline at end of file
