@@ -3,12 +3,12 @@ use rust_hdl::core::prelude::*;
 use rust_hdl::widgets::prelude::*;
 
 mod test_common;
+use rust_hdl::bsp::ok_core::prelude::*;
+use rust_hdl::bsp::ok_xem6010::pins::xem_6010_base_clock;
+use rust_hdl::hls::sdram_fifo::SDRAMFIFO;
+use rust_hdl::sim::sdr_sdram::chip::SDRAMSimulator;
 #[cfg(feature = "frontpanel")]
 use test_common::download::*;
-use rust_hdl::bsp::ok_core::prelude::*;
-use rust_hdl::sim::sdr_sdram::chip::SDRAMSimulator;
-use rust_hdl::hls::sdram_fifo::SDRAMFIFO;
-use rust_hdl::bsp::ok_xem6010::pins::xem_6010_base_clock;
 
 #[derive(LogicBlock)]
 struct SDRAMSimulatedFIFOTester {
@@ -39,7 +39,7 @@ impl SDRAMSimulatedFIFOTester {
             dl: OpalKellyDownloadFIFO::new(0xA0),
             will_write: Default::default(),
             will_read: Default::default(),
-            will_cross: Default::default()
+            will_cross: Default::default(),
         }
     }
 }
@@ -75,7 +75,7 @@ impl Logic for SDRAMSimulatedFIFOTester {
         self.dl.ok1.next = self.ok_host.ok1.val();
         self.ok_host.ok2.next = self.dl.ok2.val();
         // Link the SDRAM and the controller
-        self.sdram.data.join(&mut self.fifo.data);
+        Signal::<InOut, Bits<16>>::join(&mut self.sdram.data,&mut self.fifo.data);
         self.sdram.address.next = self.fifo.address.val();
         self.sdram.cmd.next = self.fifo.cmd.val();
         self.sdram.bank.next = self.fifo.bank.val();
@@ -92,4 +92,3 @@ fn test_opalkelly_xem_6010_sdram_simulated_fifo_download() {
     rust_hdl::bsp::ok_xem6010::synth::synth_obj(uut, target_path!("xem_6010/sdram_fifo_sim"));
     test_opalkelly_download_runtime(target_path!("xem_6010/sdram_fifo_sim/top.bit")).unwrap()
 }
-
