@@ -1,7 +1,7 @@
 use rust_hdl::core::prelude::*;
 use rust_hdl::hls::prelude::*;
 use rust_hdl::hls::spi::HLSSPIMaster;
-use rust_hdl::widgets::prelude::{SPIConfig, SPIWires};
+use rust_hdl::widgets::prelude::{SPIConfig, SPIWiresMaster};
 
 #[derive(LogicBlock)]
 struct SPITest {
@@ -12,25 +12,21 @@ struct SPITest {
     core: HLSSPIMaster<16, 8, 64>,
     pub bidi_clock: Signal<In, Clock>,
     pub sys_clock: Signal<In, Clock>,
-    pub spi: SPIWires,
+    pub spi: SPIWiresMaster,
 }
 
 impl Logic for SPITest {
     #[hdl_gen]
     fn update(&mut self) {
-        self.bidi_dev
-            .data_to_bus
-            .join(&mut self.pc_to_host.bus_read);
-        self.bidi_dev
-            .data_from_bus
-            .join(&mut self.host_to_pc.bus_write);
+        FIFOReadController::<Bits<8>>::join(&mut self.bidi_dev.data_to_bus, &mut self.pc_to_host.bus_read);
+        FIFOWriteController::<Bits<8>>::join(&mut self.bidi_dev.data_from_bus, &mut self.host_to_pc.bus_write);
         self.host_to_pc.clock.next = self.bidi_clock.val();
         self.pc_to_host.clock.next = self.bidi_clock.val();
         self.bidi_dev.clock.next = self.bidi_clock.val();
-        self.bidi_dev.bus.join(&mut self.host.bidi_bus);
+        BidiBusD::<Bits<8>>::join(&mut self.bidi_dev.bus, &mut self.host.bidi_bus);
         self.host.bidi_clock.next = self.bidi_clock.val();
         self.host.sys_clock.next = self.sys_clock.val();
-        self.host.bus.join(&mut self.core.upstream);
+        SoCBusController::<16, 8>::join(&mut self.host.bus, &mut self.core.upstream);
         self.spi.link(&mut self.core.spi);
     }
 }
