@@ -9,10 +9,14 @@ pub mod blinky;
 pub mod ddr;
 #[cfg(feature = "frontpanel")]
 pub mod download;
+pub mod fifo_tester;
+#[cfg(feature = "frontpanel")]
+pub mod fir;
 #[cfg(feature = "frontpanel")]
 pub mod mux_spi;
 #[cfg(feature = "frontpanel")]
 pub mod pipe;
+pub mod soc;
 #[cfg(feature = "frontpanel")]
 pub mod spi;
 #[cfg(feature = "frontpanel")]
@@ -21,8 +25,6 @@ pub mod tools;
 pub mod wave;
 #[cfg(feature = "frontpanel")]
 pub mod wire;
-#[cfg(feature = "frontpanel")]
-pub mod fir;
 
 pub fn snore<const P: usize>(x: u32) -> Bits<P> {
     let amp = (f64::exp(f64::sin(((x as f64) - 128.0 / 2.) * PI / 128.0)) - 0.36787944) * 108.0;
